@@ -28,6 +28,6 @@ class MailDirImport : public MailDir
     Q_OBJECT
 public:
     MailDirImport(const QString &dir);
-    void runTest() Q_DECL_OVERRIDE;
+    void runTest() override;
 };
 #endif
