@@ -35,10 +35,10 @@ using namespace Akonadi;
 
 MakeTest::MakeTest()
 {
-    connect(AgentManager::self(), SIGNAL(instanceRemoved(Akonadi::AgentInstance)),
-            this, SLOT(instanceRemoved(Akonadi::AgentInstance)));
-    connect(AgentManager::self(), SIGNAL(instanceStatusChanged(Akonadi::AgentInstance)),
-            this, SLOT(instanceStatusChanged(Akonadi::AgentInstance)));
+    connect(AgentManager::self(), &AgentManager::instanceRemoved,
+            this, &MakeTest::instanceRemoved);
+    connect(AgentManager::self(), &AgentManager::instanceStatusChanged,
+            this, &MakeTest::instanceStatusChanged);
 }
 
 void MakeTest::createAgent(const QString &name)
@@ -62,7 +62,7 @@ void MakeTest::createAgent(const QString &name)
 void MakeTest::configureDBusIface(const QString &name, const QString &dir)
 {
     QDBusInterface *configIface = new QDBusInterface(QLatin1String("org.freedesktop.Akonadi.Resource.") + currentInstance.identifier(),
-            QStringLiteral("/Settings"), QLatin1String("org.kde.Akonadi.") + name + QLatin1String(".Settings"), KDBusConnectionPool::threadConnection(), this);
+                                                     QStringLiteral("/Settings"), QLatin1String("org.kde.Akonadi.") + name + QLatin1String(".Settings"), KDBusConnectionPool::threadConnection(), this);
 
     configIface->call(QStringLiteral("setPath"), dir);
     configIface->call(QStringLiteral("setReadOnly"), true);
