@@ -22,15 +22,13 @@
 #ifndef AKONADI_KMIME_MESSAGESTATUS_H
 #define AKONADI_KMIME_MESSAGESTATUS_H
 
-#include <QtCore/QSet>
+#include <QSet>
 
 #include "akonadi-mime_export.h"
 
 class QString;
 
-namespace Akonadi
-{
-
+namespace Akonadi {
 //---------------------------------------------------------------------------
 /**
   @short Akonadi KMime Message Status.
@@ -428,7 +426,6 @@ public:
 private:
     quint32 mStatus;
 };
-
 } // namespace Akonadi
 
 #endif
