@@ -30,12 +30,11 @@
 
 class Q_DECL_HIDDEN Akonadi::RemoveDuplicatesJob::Private
 {
-
 public:
     Private(RemoveDuplicatesJob *parent)
         : mJobCount(0)
         , mKilled(false)
-        , mCurrentJob(0)
+        , mCurrentJob(nullptr)
         , mParent(parent)
     {
     }
@@ -48,7 +47,10 @@ public:
         Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(collection, mParent);
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
         job->fetchScope().fetchFullPayload();
-        mParent->connect(job, SIGNAL(result(KJob*)), mParent, SLOT(slotFetchDone(KJob*)));
+        job->fetchScope().setIgnoreRetrievalErrors(true);
+        mParent->connect(job, &ItemFetchJob::result, mParent, [this](KJob *job) {
+            slotFetchDone(job);
+        });
         mCurrentJob = job;
 
         Q_EMIT mParent->description(mParent, i18n("Retrieving items..."));
@@ -130,7 +132,9 @@ public:
             } else {
                 Q_EMIT mParent->description(mParent, i18n("Removing duplicates..."));
                 Akonadi::ItemDeleteJob *delCmd = new Akonadi::ItemDeleteJob(mDuplicateItems, mParent);
-                mParent->connect(delCmd, SIGNAL(result(KJob*)), mParent, SLOT(slotDeleteDone(KJob*)));
+                mParent->connect(delCmd, &ItemDeleteJob::result, mParent, [this](KJob *job) {
+                    slotDeleteDone(job);
+                });
             }
         }
     }
@@ -147,12 +151,11 @@ public:
     Akonadi::Collection::List mFolders;
     int mJobCount;
     Akonadi::Item::List mDuplicateItems;
-    bool mKilled;
-    Akonadi::Job *mCurrentJob;
+    bool mKilled = false;
+    Akonadi::Job *mCurrentJob = nullptr;
 
 private:
-    RemoveDuplicatesJob *mParent;
-
+    RemoveDuplicatesJob *mParent = nullptr;
 };
 
 using namespace Akonadi;
